@@ -25,6 +25,8 @@ pub(crate) fn build_cluster_descriptor(
                 .iter()
                 .map(|stream_node| OperatorDescriptor {
                     operator_id: stream_node.id,
+                    input_schema: stream_node.input_schema.clone(),
+                    output_schema: stream_node.output_schema.clone(),
                     checkpoint_id: CheckpointId::default(),
                     completed_checkpoint_id: None,
                     checkpoint_handle: None,
@@ -59,7 +61,7 @@ pub(crate) fn build_cluster_descriptor(
         version: crate::utils::VERSION.to_owned(),
         application_id: context.application_id.clone(),
         application_properties: application_properties.clone(),
-        coordinator_address: "".to_string(),
+        web_address: "".to_string(),
         metrics_address: context.metric_addr.clone(),
         coordinator_status: ManagerStatus::Pending,
         v_cores: context.v_cores,
